# Input components in `ng`

Name | Description
--- | ---
input[text] | Standard HTML text input with angular data binding, inherited by most of the `input` elements.
input[date] | Input with date validation and transformation. In browsers that do not yet support the HTML5 date input, a text element will be used. In that case, text must be entered in a valid ISO-8601 date format (yyyy-MM-dd), for example: `2009-01-06`. Since many modern browsers do not yet support this input type, it is important to provide cues to users on the expected input format via a placeholder or label.
input[datetime-local] | Input with datetime validation and transformation. In browsers that do not yet support the HTML5 date input, a text element will be used. In that case, the text must be entered in a valid ISO-8601 local datetime format (yyyy-MM-ddTHH:mm:ss), for example: `2010-12-28T14:57:00`.
input[time] | Input with time validation and transformation. In browsers that do not yet support the HTML5 time input, a text element will be used. In that case, the text must be entered in a valid ISO-8601 local time format (HH:mm:ss), for example: `14:57:00`. Model must be a Date object. This binding will always output a Date object to the model of January 1, 1970, or local date `new Date(1970, 0, 1, HH, mm, ss)`.
input[week] | Input with week-of-the-year validation and transformation to Date. In browsers that do not yet support the HTML5 week input, a text element will be used. In that case, the text must be entered in a valid ISO-8601 week format (yyyy-W##), for example: `2013-W02`.
input[month] | Input with month validation and transformation. In browsers that do not yet support the HTML5 month input, a text element will be used. In that case, the text must be entered in a valid ISO-8601 month format (yyyy-MM), for example: `2009-01`.
input[number] | Text input with number validation and transformation. Sets the `number` validation error if not a valid number.
input[url] | Text input with URL validation. Sets the `url` validation error key if the content is not a valid URL.
input[email] | Text input with email validation. Sets the `email` validation error key if not a valid email address.
input[radio] | HTML radio button.
input[range] | Native range input with validation and transformation.
input[checkbox] | HTML checkbox.